@@ -35,6 +35,16 @@ CONFIG_OPTION_OUTPUT = "output"
 conf:ConfigParser = ConfigParser()
 
 # help function -------->
+def progress(progress = 1.0, prefix="", postfix="", default_terminal_width = 80):
+    try:
+        import os
+        w = os.get_terminal_size()[0] - len(prefix) - len(postfix)
+    except:
+        w = default_terminal_width - len(prefix) - len(postfix)
+    filled = min(int(w * progress), w)
+    empty = max(int(w - filled), 0)
+    return f"\r{prefix}{{:█<{filled:d}s}}{{:░<{empty:d}s}}{postfix}".format("", "")
+
 def print_progress(p, t, sub_p, sub_t, op, name):
     if t == 0:
         count = ""
@@ -42,9 +52,13 @@ def print_progress(p, t, sub_p, sub_t, op, name):
         count = "{}/{} ".format(p, t)
     if sub_t == 0:
         proc = ""
+        proc_value = 0.0
     else:
-        proc = "{:.2f}%    ".format(sub_p*100/sub_t)
-    print("{}\r {}{}{}: {}".format(" "*80, count, proc, op, name), end="\r")
+        proc = "{:.2f}%".format(sub_p*100/sub_t)
+        proc_value = sub_p/sub_t
+    prefix = "{}: {} ".format(op, name)
+    postfix = " {} {}".format(proc, count)
+    print(progress(proc_value, prefix, postfix), end="")
 
 def clear_console(message="Done."):
     print("{}\r{}".format(" "*80, message))
